@@ -1,4 +1,4 @@
-# Copyright (C) 2016-2022 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -24,7 +24,7 @@ import dns.resolver
 
 from dns.exception import DNSException
 from email.utils import parseaddr
-from importlib_resources import read_binary
+from importlib.resources import read_binary
 from lazr.config import as_timedelta
 from mailman.config import config
 from mailman.core.i18n import _
@@ -34,7 +34,7 @@ from mailman.utilities.datetime import now
 from mailman.utilities.protocols import get
 from mailman.utilities.string import wrap
 from public import public
-from requests.exceptions import HTTPError
+from requests.exceptions import RequestException
 from urllib.error import URLError
 from zope.interface import implementer
 
@@ -75,7 +75,7 @@ def ensure_current_suffix_list():
     if download:
         try:
             content = get(config.dmarc.org_domain_data_url)
-        except (URLError, HTTPError) as error:
+        except (URLError, RequestException) as error:
             elog.error('Unable to retrieve public suffix list from %s: %s',
                        config.dmarc.org_domain_data_url,
                        getattr(error, 'reason', str(error)))
@@ -279,8 +279,16 @@ def is_reject_or_quarantine(mlist, email, dmarc_domain, org=False):
 
 def maybe_mitigate(mlist, email):
     # This takes an email address, and returns True if DMARC policy is
-    # p=reject or p=quarantine.
+    # p=reject or p=quarantine or if the address matches dmarc_addresses.
     email = email.lower()
+    for address in mlist.dmarc_addresses:
+        if address.startswith('^'):
+            # It's a regexp.
+            if re.search(address, email, re.I):
+                return True
+        else:
+            if address.lower() == email:
+                return True
     # Scan from the right in case quoted local part has an '@'.
     local, at, from_domain = email.rpartition('@')
     if at != '@':
